@@ -19,6 +19,7 @@ from ..utils import (
 from dataclasses import dataclass, field
 from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
+
 @dataclass
 class VehicleMonitoringConfig(BaseConfig):
     """Configuration for vehicle monitoring use case."""
@@ -37,15 +38,17 @@ class VehicleMonitoringConfig(BaseConfig):
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            1: "bicycle",
+            0: "ambulance",
+            1: "army vehicle",
             2: "car",
-            3: "motorbike",
-            4: "auto rickshaw",
-            5: "bus",
+            3: "bicycle",
+            4: "bus",
+            5: "auto rickshaw",
             6: "garbagevan",
             7: "truck",
             8: "minibus",
-            10: "army vehicle",
+            9: "minivan",
+            10: "motorbike",
             11: "pickup",
             12: "policecar",
             13: "rickshaw",
@@ -55,10 +58,11 @@ class VehicleMonitoringConfig(BaseConfig):
             17: "three wheelers -CNG-",
             18: "human hauler",
             19: "van",
-            20: "wheelbarrow",
+            20: "wheelbarrow"
         }
     )
 
+
 class VehicleMonitoringUseCase(BaseProcessor):
     CATEGORY_DISPLAY = {
         "bicycle": "Bicycle",
@@ -155,7 +159,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
         self._total_frame_counter += 1
 
         frame_number = None
-        if isinstance(stream_info, dict):
+        if stream_info:
             input_settings = stream_info.get("input_settings", {})
             start_frame = input_settings.get("start_frame")
             end_frame = input_settings.get("end_frame")
@@ -463,7 +467,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
 
     def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False) -> str:
         if not stream_info or isinstance(stream_info, str):
-            return "00:00:00.00" if precision else "00:00:00"
+            return "00:00:00.00" if not precision else "00:00:00.000000"
         if precision:
             if stream_info.get("feed_type", "live") == "disk":
                 start_time = stream_info.get("start_frame", 30) / stream_info.get("original_fps", 30)
@@ -474,7 +478,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
             start_time = stream_info.get("start_frame", 30) / stream_info.get("original_fps", 30)
             return self._format_timestamp_for_video(start_time)
         else:
-            stream_time_str = stream_info.get("stream_info", {}).get("stream_time", "")
+            stream_time_str = stream_info.get("stream_info", {}).get("stream_time", "") if isinstance(stream_info.get("stream_info"), dict) else ""
             if stream_time_str:
                 try:
                     timestamp_str = stream_time_str.replace(" UTC", "")
@@ -488,7 +492,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
 
     def _get_start_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False) -> str:
         if not stream_info or isinstance(stream_info, str):
-            return "00:00:00"
+            return "00:00:00" if not precision else "00:00:00.000000"
         if precision:
             if stream_info.get("feed_type", "live") == "disk":
                 return "00:00:00"
@@ -498,7 +502,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
             return "00:00:00"
         else:
             if self._tracking_start_time is None:
-                stream_time_str = stream_info.get("stream_info", {}).get("stream_time", "")
+                stream_time_str = stream_info.get("stream_info", {}).get("stream_time", "") if isinstance(stream_info.get("stream_info"), dict) else ""
                 if stream_time_str:
                     try:
                         timestamp_str = stream_time_str.replace(" UTC", "")
